==> huaweicloudsdkgaussdbforopengauss-3.1.75-py2.py3-none-any.whl: huaweicloudsdkgaussdbforopengauss/v3/model/list_db_users_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListDbUsersResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'users': 'list[GaussDBforOpenGaussUserForList]',
        'total_count': 'int'
    }

    attribute_map = {
        'users': 'users',
        'total_count': 'total_count'
    }

    def __init__(self, users=None, total_count=None):
        """ListDbUsersResponse

        The model defined in huaweicloud sdk

        :param users: 列表中每个元素表示一个数据库用户。
        :type users: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.GaussDBforOpenGaussUserForList`]
        :param total_count: 数据库用户总数。
        :type total_count: int
        """
        
        super(ListDbUsersResponse, self).__init__()

        self._users = None
        self._total_count = None
        self.discriminator = None

        if users is not None:
            self.users = users
        if total_count is not None:
            self.total_count = total_count

    @property
    def users(self):
        """Gets the users of this ListDbUsersResponse.

        列表中每个元素表示一个数据库用户。

        :return: The users of this ListDbUsersResponse.
        :rtype: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.GaussDBforOpenGaussUserForList`]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this ListDbUsersResponse.

        列表中每个元素表示一个数据库用户。

        :param users: The users of this ListDbUsersResponse.
        :type users: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.GaussDBforOpenGaussUserForList`]
        """
        self._users = users

    @property
    def total_count(self):
        """Gets the total_count of this ListDbUsersResponse.

        数据库用户总数。

        :return: The total_count of this ListDbUsersResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ListDbUsersResponse.

        数据库用户总数。

        :param total_count: The total_count of this ListDbUsersResponse.
        :type total_count: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDbUsersResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdbforopengauss-3.1.143-py2.py3-none-any.whl: huaweicloudsdkgaussdbforopengauss/v3/model/list_db_users_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListDbUsersResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'users': 'list[GaussDBforOpenGaussUserForList]',
        'total_count': 'int'
    }

    attribute_map = {
        'users': 'users',
        'total_count': 'total_count'
    }

    def __init__(self, users=None, total_count=None):
        r"""ListDbUsersResponse

        The model defined in huaweicloud sdk

        :param users: 列表中每个元素表示一个数据库用户。
        :type users: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.GaussDBforOpenGaussUserForList`]
        :param total_count: 数据库用户总数。
        :type total_count: int
        """
        
        super(ListDbUsersResponse, self).__init__()

        self._users = None
        self._total_count = None
        self.discriminator = None

        if users is not None:
            self.users = users
        if total_count is not None:
            self.total_count = total_count

    @property
    def users(self):
        r"""Gets the users of this ListDbUsersResponse.

        列表中每个元素表示一个数据库用户。

        :return: The users of this ListDbUsersResponse.
        :rtype: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.GaussDBforOpenGaussUserForList`]
        """
        return self._users

    @users.setter
    def users(self, users):
        r"""Sets the users of this ListDbUsersResponse.

        列表中每个元素表示一个数据库用户。

        :param users: The users of this ListDbUsersResponse.
        :type users: list[:class:`huaweicloudsdkgaussdbforopengauss.v3.GaussDBforOpenGaussUserForList`]
        """
        self._users = users

    @property
    def total_count(self):
        r"""Gets the total_count of this ListDbUsersResponse.

        数据库用户总数。

        :return: The total_count of this ListDbUsersResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        r"""Sets the total_count of this ListDbUsersResponse.

        数据库用户总数。

        :param total_count: The total_count of this ListDbUsersResponse.
        :type total_count: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDbUsersResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
